@@ -44,13 +44,12 @@ import java.util.function.Function;
  */
 public class ParsingUtils {
 
-    public static Map<Object, Color> colorCache = new WeakHashMap<>(100);
+    public static final Map<Object, Color> colorCache = new WeakHashMap<>(100);
+
+    private static URLHelperFactory urlHelperFactory = RemoteURLHelper::new;
 
     // HTML 4.1 color table,  + orange and magenta
-    static Map<String, String> colorSymbols = new HashMap();
-
-    private static final Class defaultUrlHelperClass = RemoteURLHelper.class;
-    public static Class urlHelperClass = defaultUrlHelperClass;
+    private static Map<String, String> colorSymbols = new HashMap();
 
     static {
         colorSymbols.put("white", "FFFFFF");
@@ -423,50 +422,34 @@ public class ParsingUtils {
     }
 
     /**
-     * Return the registered URLHelper, constructed with the provided URL
-     * @see #registerHelperClass(Class)
+     * Return a URLHelper from the current URLHelperFactory
+     * @see #setURLHelperFactory(URLHelperFactory) 
+     *
      * @param url
      * @return
      */
     public static URLHelper getURLHelper(URL url) {
-        try {
-            return getURLHelper(urlHelperClass, url);
-        } catch (Exception e) {
-            return getURLHelper(defaultUrlHelperClass, url);
-        }
-    }
-
-    private static URLHelper getURLHelper(Class helperClass, URL url) {
-        try {
-            Constructor constr = helperClass.getConstructor(URL.class);
-            return (URLHelper) constr.newInstance(url);
-        } catch (Exception e) {
-            String errMsg = "Error instantiating url helper for class: " + helperClass;
-            throw new IllegalStateException(errMsg, e);
-        }
+            return urlHelperFactory.getHelper(url);
     }
 
     /**
-     * Register a {@code URLHelper} class to be used for URL operations. The helper
-     * may be used for both FTP and HTTP operations, so if any FTP URLs are used
-     * the {@code URLHelper} must support it.
+     * Set the factory object for providing URLHelpers.  {@see URLHelperFactory}.
      *
-     * The default helper class is {@link RemoteURLHelper}, which delegates to FTP/HTTP
-     * helpers as appropriate.
-     *
-     * @see URLHelper
-     * @param helperClass Class which implements {@link URLHelper}, and have a constructor
-     *                    which takes a URL as it's only argument.
+     * @param factory
      */
-    public static void registerHelperClass(Class helperClass) {
-        if (!URLHelper.class.isAssignableFrom(helperClass)) {
-            throw new IllegalArgumentException("helperClass must implement URLHelper");
-            //TODO check that it has 1 arg constructor of proper type
+    public static void setURLHelperFactory(URLHelperFactory factory) {
+        if(factory == null) {
+            throw new NullPointerException("Null URLHelperFactory");
         }
-        urlHelperClass = helperClass;
+        urlHelperFactory = factory;
+    }
+
+    public static URLHelperFactory getURLHelperFactory() {
+        return urlHelperFactory;
     }
 
     /**
+     *
      * Add the {@code indexExtension} to the {@code filepath}, preserving
      * query string elements if present. Intended for use where {@code filepath}
      * is a URL. Will behave correctly on regular file paths (just add the extension
