@@ -25,6 +25,7 @@
 
 package htsjdk.variant.variantcontext;
 
+import htsjdk.beta.plugin.HtsRecord;
 import htsjdk.tribble.Feature;
 import htsjdk.tribble.TribbleException;
 import htsjdk.tribble.util.ParsingUtils;
@@ -222,7 +223,7 @@ import java.util.stream.Collectors;
  * <!-- </s3> -->
  *
  */
-public class VariantContext implements Feature, Serializable {
+public class VariantContext implements HtsRecord, Feature, Serializable {
     public static final long serialVersionUID = 1L;
 
     private static final boolean WARN_ABOUT_BAD_END = true;
@@ -242,6 +243,9 @@ public class VariantContext implements Feature, Serializable {
     /** The type (cached for performance reasons) of this context */
     protected Type type = null;
 
+    /** The type of this context, cached separately if ignoreNonRef is true */
+    protected Type typeIgnoringNonRef = null;
+
     /** A set of the alleles segregating in this context */
     protected final List<Allele> alleles;
 
@@ -665,10 +669,29 @@ public class VariantContext implements Feature, Serializable {
      * @return the type of this VariantContext
      **/
     public Type getType() {
-        if ( type == null )
-            determineType();
+        return getType(false);
+    }
 
-        return type;
+    /**
+     * Determines (if necessary) and returns the type of this variation by examining the alleles it contains.
+     *
+     * @param ignoreNonRef If set to true, symbolic NON_REF alleles will not be considered for the type determination,
+     *                     which is required for handling GVCF files.
+     * @return the type of this VariantContext
+     **/
+    public Type getType(final boolean ignoreNonRef) {
+        // Make sure we use the correct cached result
+        if (ignoreNonRef) {
+            if (typeIgnoringNonRef == null) {
+                typeIgnoringNonRef = determineType(ignoreNonRef);
+            }
+            return typeIgnoringNonRef;
+        } else {
+            if (type == null) {
+                type = determineType(ignoreNonRef);
+            }
+            return type;
+        }
     }
 
     /**
@@ -884,7 +907,17 @@ public class VariantContext implements Feature, Serializable {
      * @return The allele sharing the same bases as this byte[], or null if no such allele is present.
      */
     public Allele getAllele(byte[] allele) {
-        return Allele.getMatchingAllele(getAlleles(), allele);
+
+        if (Allele.NO_CALL.basesMatch(allele)) {
+            return Allele.NO_CALL;
+        } else {
+            for ( Allele a : getAlleles() ) {
+                if ( a.basesMatch(allele) ) {
+                    return a;
+                }
+            }
+            return null;
+        }
     }
 
     /**
@@ -1123,8 +1156,10 @@ public class VariantContext implements Feature, Serializable {
         GenotypesContext genotypes = sampleIds.isEmpty() ? getGenotypes() : getGenotypes(sampleIds);
 
         for ( final Genotype g : genotypes) {
-            for ( final Allele a : g.getAlleles() )
-                n += a.isNoCall() ? 0 : 1;
+            if (!g.isFiltered()) {
+                for ( final Allele a : g.getAlleles() )
+                    n += a.isNoCall() ? 0 : 1;
+            }
         }
 
         return n;
@@ -1152,7 +1187,9 @@ public class VariantContext implements Feature, Serializable {
         GenotypesContext genotypes = sampleIds.isEmpty() ? getGenotypes() : getGenotypes(sampleIds);
 
         for ( final Genotype g : genotypes ) {
-            n += g.countAllele(a);
+            if (!g.isFiltered()) {
+                n += g.countAllele(a);
+            }
         }
 
         return n;
@@ -1415,30 +1452,34 @@ public class VariantContext implements Feature, Serializable {
     //
     // ---------------------------------------------------------------------------------------------------------
 
-    private void determineType() {
-        if ( type == null ) {
-            switch ( getNAlleles() ) {
-                case 0:
-                    throw new IllegalStateException("Unexpected error: requested type of VariantContext with no alleles!" + this);
-                case 1:
-                    // note that this doesn't require a reference allele.  You can be monomorphic independent of having a
-                    // reference allele
-                    type = Type.NO_VARIATION;
-                    break;
-                default:
-                    determinePolymorphicType();
-            }
+    private Type determineType(final boolean ignoreNonRef) {
+        switch ( getNAlleles() ) {
+            case 0:
+                throw new IllegalStateException("Unexpected error: requested type of VariantContext with no alleles!" + this);
+            case 1:
+                // note that this doesn't require a reference allele.  You can be monomorphic independent of having a
+                // reference allele
+                return Type.NO_VARIATION;
+            default:
+                return determinePolymorphicType(ignoreNonRef);
         }
     }
 
-    private void determinePolymorphicType() {
-        type = null;
+    private Type determinePolymorphicType(final boolean ignoreNonRef) {
+        Type type = null;
+        boolean nonRefAlleleFound = false;
 
         // do a pairwise comparison of all alleles against the reference allele
         for ( Allele allele : alleles ) {
             if ( allele == REF )
                 continue;
 
+            // If we see a NON_REF allele and need to ignore it, skip this allele, but signal that we have seen one
+            if (ignoreNonRef && allele.isNonRefAllele()) {
+                nonRefAlleleFound = true;
+                continue;
+            }
+
             // find the type of this allele relative to the reference
             Type biallelicType = typeOfBiallelicVariant(REF, allele);
 
@@ -1448,10 +1489,15 @@ public class VariantContext implements Feature, Serializable {
             }
             // if the type of this allele is different from that of a previous one, assign it the MIXED type and quit
             else if ( biallelicType != type ) {
-                type = Type.MIXED;
-                return;
+                return Type.MIXED;
             }
         }
+        // If all alt alleles are NON_REF alleles and ignoreNonRef is true, type will still be null. Therefore, if we
+        // have only seen NON_REFs, choose SYMBOLIC
+        if (type == null && nonRefAlleleFound) {
+            return Type.NO_VARIATION;
+        }
+        return type;
     }
 
     private static Type typeOfBiallelicVariant(Allele ref, Allele allele) {
